@@ -10,6 +10,7 @@ import re
 import subprocess
 import logging
 from sys import platform
+import json
 
 from embedops_cli.utilities import quote_str_for_platform
 from embedops_cli import environment_utilities as envutil
@@ -89,6 +90,7 @@ def docker_run(run_context: LocalRunContext):
         "registry_token_secret"
     )
     run_context.variables.update(aws_token_data)
+    run_context.variables.update({"EMBEDOPS_VARS": json.dumps(run_context.variables)})
 
     envutil.create_job_env_file(run_context.variables)
 
