@@ -6,6 +6,8 @@ CLI interface for EmbedOps tools
 """
 import sys
 import logging
+import platform
+import subprocess
 import click
 
 # import embedops_cli.yaml_tools.yaml_utilities as yaml_utilities
@@ -13,6 +15,7 @@ from embedops_cli.yaml_tools import yaml_utilities
 from . import docker_run, version, embedops_authorization, telemetry
 from .eo_types import (
     BadYamlFileException,
+    NoDockerCLIException,
     DockerNotRunningException,
     EmbedOpsException,
     LoginFailureException,
@@ -96,6 +99,9 @@ def _say_token_is_good(token_name: str):
 def login(test):
     """Log in to the EmbedOps platform.
     You will be prompted to enter your EmbedOps credentials if you are not logged in."""
+
+    docker_is_installed_and_running()
+
     token = embedops_authorization.get_auth_token()
 
     if token and embedops_authorization.check_token():
@@ -180,6 +186,8 @@ def run(ctx: click.Context, job_name):
 
     telemetry.command_event("jobs_run", {"job_name": job_name})
 
+    docker_is_installed_and_running()
+
     # check if token has expired if so try to get a new token
     if embedops_authorization.is_registery_token_valid() is False:
         embedops_authorization.login_to_registry()
@@ -383,5 +391,30 @@ def _echo_error_and_fix(exc):
     click.secho("-" * 80 + "\n", fg="bright_red")
 
 
+def docker_is_installed_and_running():
+    """Check if docker is installed and running"""
+    try:
+        try:
+            subprocess.check_output(
+                ("powershell " if platform.system() == "Windows" else "")
+                + "docker info",
+                shell=True,
+                stderr=subprocess.DEVNULL,
+            )
+        except subprocess.CalledProcessError as err:
+            if err.returncode == 127:
+                raise NoDockerCLIException from err
+            if "Is the docker daemon running?" in str(err.stdout):
+                raise DockerNotRunningException from err
+            raise UnknownDockerException from err
+    except (
+        NoDockerCLIException,
+        DockerNotRunningException,
+        UnknownDockerException,
+    ) as err:
+        _echo_error_and_fix(err)
+        sys.exit(1)
+
+
 if __name__ == "__main__":
     embedops_cli(prog_name="embedops-cli")  # pylint:disable=unexpected-keyword-arg
