@@ -16,5 +16,5 @@ SIZE_PATTERN = (
     r"(?P<ram_size>\d+)\s+"
     r"(?P<dec>\d+)\s+"
     r"(?P<hex>[a-fA-F0-9]+)\s+"
-    r"(?P<build_output_filename>\S+)"
+    r"(?P<target_name>\S+)"
 )
